/*
*******************************************************************************
**
**  This device driver was created by Applilet for the 78K0S/KB1+, 78K0S/KA1+,
**  78K0S/KY1+ 8-Bit Single-Chip Microcontrollers.
**
**  Copyright(C) NEC Electronics Corporation 2002-2006
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	serial.c
**  Abstract :	This file implements device driver for serial module.
**  APIlib :	NEC78K0SKX1+.lib E1.46h [16 Feb. 2006]
**
**  Device :	uPD78F9222
**
**  Compiler :	NEC/CC78K0
**
*******************************************************************************
*/


/*
*******************************************************************************
**  Include files
*******************************************************************************
*/
#include "macrodriver.h"
#include "serial.h"
/* UART6 Transmission */
UCHAR* UART6_TX_ADDRESS;	/* UART6 transfer buffer address */
UCHAR UART6_TX_CNT;		/* UART6 transfer number */

/* UART6 Reception */
UCHAR* UART6_RX_ADDRESS;	/* UART6 receive buffer address */
UCHAR UART6_RX_CNT;		/* UART6 recieve data number */
UCHAR UART6_RX_LEN;		/* UART6 recieve data count number */

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function initializes UART6 module.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void UART6_Init( void )
{
	ASIM6 = 1;

	SetIORBit(PM4, 0x10);		/* port setting in receive mode */
	
	SetIORBit(ASIM6, 0x04);		/* data length 8 bits */
	ClrIORBit(ASIM6, 0x02);		/* stop length 1 bit */
	ClrIORBit(ASIM6, 0x18);		/* none parity mode */
	SetIORBit(ASICL6, 0x02);	/* LSB-first transfer */

	CKSR6 = UART_BAUDRATE_M6;	/* baudrate selection */
	BRGC6 = UART_BAUDRATE_K6;

	ClrIORBit(IF1, 0x20);
	ClrIORBit(MK1, 0x20);		/* UART6 recieve end interrupt enable */
	SetIORBit(ASIM6, 0x80);
	SetIORBit(ASIM6, 0x20);		/* UART6 receive mode */
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function is responsible for UART6 data receiving.
**
**  Parameters:
**	rxbuf :	Header point of receive buffer.
**	rxnum :	The size of receive buffer.
**
**  Returns:
**	MD_ERROR :	When an error argument input.
**	MD_OK :		When transfer success.
**
**-----------------------------------------------------------------------------
*/
MD_STATUS UART6_ReceiveData( UCHAR* rxbuf, UCHAR rxnum )
{
	if(rxnum < 1){
		return MD_ERROR;
	}

	UART6_RX_CNT = 0;
	UART6_RX_LEN = rxnum;
	UART6_RX_ADDRESS = rxbuf;

	return MD_OK;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function is the UART6 receive end interrupt handler.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
